@@ -117,7 +117,7 @@ class AssetServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=60.0,
@@ -133,7 +133,7 @@ class AssetServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=60.0,
@@ -146,7 +146,7 @@ class AssetServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=60.0,
@@ -162,7 +162,7 @@ class AssetServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=60.0,
@@ -175,7 +175,7 @@ class AssetServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=15.0,
@@ -188,12 +188,28 @@ class AssetServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=15.0,
                 client_info=client_info,
             ),
+            self.analyze_iam_policy: gapic_v1.method.wrap_method(
+                self.analyze_iam_policy,
+                default_retry=retries.Retry(
+                    initial=0.1,
+                    maximum=60.0,
+                    multiplier=1.3,
+                    predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                ),
+                default_timeout=300.0,
+                client_info=client_info,
+            ),
+            self.analyze_iam_policy_longrunning: gapic_v1.method.wrap_method(
+                self.analyze_iam_policy_longrunning,
+                default_timeout=60.0,
+                client_info=client_info,
+            ),
         }
 
     @property
@@ -294,5 +310,26 @@ class AssetServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def analyze_iam_policy(
+        self,
+    ) -> typing.Callable[
+        [asset_service.AnalyzeIamPolicyRequest],
+        typing.Union[
+            asset_service.AnalyzeIamPolicyResponse,
+            typing.Awaitable[asset_service.AnalyzeIamPolicyResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def analyze_iam_policy_longrunning(
+        self,
+    ) -> typing.Callable[
+        [asset_service.AnalyzeIamPolicyLongrunningRequest],
+        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+    ]:
+        raise NotImplementedError()
+
 
 __all__ = ("AssetServiceTransport",)
