@@ -92,10 +92,10 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
                 for grpc channel. It is ignored if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
 
         Raises:
@@ -104,6 +104,8 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
           google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
+        self._ssl_channel_credentials = ssl_channel_credentials
+
         if channel:
             # Sanity check: Ensure that channel and credentials are not both
             # provided.
@@ -111,6 +113,7 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
 
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
+            self._ssl_channel_credentials = None
         elif api_mtls_endpoint:
             warnings.warn(
                 "api_mtls_endpoint and client_cert_source are deprecated",
@@ -147,6 +150,7 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
                 scopes=scopes or self.AUTH_SCOPES,
                 quota_project_id=quota_project_id,
             )
+            self._ssl_channel_credentials = ssl_credentials
         else:
             host = host if ":" in host else host + ":443"
 
@@ -224,12 +228,8 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Create the channel designed to connect to this service.
-
-        This property caches on the instance; repeated calls return
-        the same channel.
+        """Return the channel designed to connect to this service.
         """
-        # Return the channel from cache.
         return self._grpc_channel
 
     @property
@@ -514,5 +514,75 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
             )
         return self._stubs["search_all_iam_policies"]
 
+    @property
+    def analyze_iam_policy(
+        self,
+    ) -> Callable[
+        [asset_service.AnalyzeIamPolicyRequest], asset_service.AnalyzeIamPolicyResponse
+    ]:
+        r"""Return a callable for the analyze iam policy method over gRPC.
+
+        Analyzes IAM policies to answer which identities have
+        what accesses on which resources.
+
+        Returns:
+            Callable[[~.AnalyzeIamPolicyRequest],
+                    ~.AnalyzeIamPolicyResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "analyze_iam_policy" not in self._stubs:
+            self._stubs["analyze_iam_policy"] = self.grpc_channel.unary_unary(
+                "/google.cloud.asset.v1.AssetService/AnalyzeIamPolicy",
+                request_serializer=asset_service.AnalyzeIamPolicyRequest.serialize,
+                response_deserializer=asset_service.AnalyzeIamPolicyResponse.deserialize,
+            )
+        return self._stubs["analyze_iam_policy"]
+
+    @property
+    def analyze_iam_policy_longrunning(
+        self,
+    ) -> Callable[
+        [asset_service.AnalyzeIamPolicyLongrunningRequest], operations.Operation
+    ]:
+        r"""Return a callable for the analyze iam policy longrunning method over gRPC.
+
+        Analyzes IAM policies asynchronously to answer which identities
+        have what accesses on which resources, and writes the analysis
+        results to a Google Cloud Storage or a BigQuery destination. For
+        Cloud Storage destination, the output format is the JSON format
+        that represents a
+        [AnalyzeIamPolicyResponse][google.cloud.asset.v1.AnalyzeIamPolicyResponse].
+        This method implements the
+        [google.longrunning.Operation][google.longrunning.Operation],
+        which allows you to track the operation status. We recommend
+        intervals of at least 2 seconds with exponential backoff retry
+        to poll the operation result. The metadata contains the request
+        to help callers to map responses to requests.
+
+        Returns:
+            Callable[[~.AnalyzeIamPolicyLongrunningRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "analyze_iam_policy_longrunning" not in self._stubs:
+            self._stubs[
+                "analyze_iam_policy_longrunning"
+            ] = self.grpc_channel.unary_unary(
+                "/google.cloud.asset.v1.AssetService/AnalyzeIamPolicyLongrunning",
+                request_serializer=asset_service.AnalyzeIamPolicyLongrunningRequest.serialize,
+                response_deserializer=operations.Operation.FromString,
+            )
+        return self._stubs["analyze_iam_policy_longrunning"]
+
 
 __all__ = ("AssetServiceGrpcTransport",)
