@@ -19,6 +19,7 @@ import proto  # type: ignore
 
 
 from google.cloud.asset_v1.types import assets as gca_assets
+from google.protobuf import duration_pb2 as duration  # type: ignore
 from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
 from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 from google.type import expr_pb2 as expr  # type: ignore
@@ -51,6 +52,12 @@ __protobuf__ = proto.module(
         "SearchAllResourcesResponse",
         "SearchAllIamPoliciesRequest",
         "SearchAllIamPoliciesResponse",
+        "IamPolicyAnalysisQuery",
+        "AnalyzeIamPolicyRequest",
+        "AnalyzeIamPolicyResponse",
+        "IamPolicyAnalysisOutputConfig",
+        "AnalyzeIamPolicyLongrunningRequest",
+        "AnalyzeIamPolicyLongrunningResponse",
     },
 )
 
@@ -62,6 +69,7 @@ class ContentType(proto.Enum):
     IAM_POLICY = 2
     ORG_POLICY = 4
     ACCESS_POLICY = 5
+    OS_INVENTORY = 6
 
 
 class ExportAssetsRequest(proto.Message):
@@ -525,7 +533,7 @@ class FeedOutputConfig(proto.Message):
     """
 
     pubsub_destination = proto.Field(
-        proto.MESSAGE, number=1, oneof="destination", message=PubsubDestination,
+        proto.MESSAGE, number=1, oneof="destination", message="PubsubDestination",
     )
 
 
@@ -598,7 +606,9 @@ class Feed(proto.Message):
 
     content_type = proto.Field(proto.ENUM, number=4, enum="ContentType",)
 
-    feed_output_config = proto.Field(proto.MESSAGE, number=5, message=FeedOutputConfig,)
+    feed_output_config = proto.Field(
+        proto.MESSAGE, number=5, message="FeedOutputConfig",
+    )
 
     condition = proto.Field(proto.MESSAGE, number=6, message=expr.Expr,)
 
@@ -825,4 +835,426 @@ class SearchAllIamPoliciesResponse(proto.Message):
     next_page_token = proto.Field(proto.STRING, number=2)
 
 
+class IamPolicyAnalysisQuery(proto.Message):
+    r"""IAM policy analysis query message.
+
+    Attributes:
+        scope (str):
+            Required. The relative name of the root asset. Only
+            resources and IAM policies within the scope will be
+            analyzed.
+
+            This can only be an organization number (such as
+            "organizations/123"), a folder number (such as
+            "folders/123"), a project ID (such as
+            "projects/my-project-id"), or a project number (such as
+            "projects/12345").
+
+            To know how to get organization id, visit
+            `here <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
+
+            To know how to get folder or project id, visit
+            `here <https://cloud.google.com/resource-manager/docs/creating-managing-folders#viewing_or_listing_folders_and_projects>`__.
+        resource_selector (~.asset_service.IamPolicyAnalysisQuery.ResourceSelector):
+            Optional. Specifies a resource for analysis.
+        identity_selector (~.asset_service.IamPolicyAnalysisQuery.IdentitySelector):
+            Optional. Specifies an identity for analysis.
+        access_selector (~.asset_service.IamPolicyAnalysisQuery.AccessSelector):
+            Optional. Specifies roles or permissions for
+            analysis. This is optional.
+        options (~.asset_service.IamPolicyAnalysisQuery.Options):
+            Optional. The query options.
+    """
+
+    class ResourceSelector(proto.Message):
+        r"""Specifies the resource to analyze for access policies, which
+        may be set directly on the resource, or on ancestors such as
+        organizations, folders or projects.
+
+        Attributes:
+            full_resource_name (str):
+                Required. The [full resource name]
+                (https://cloud.google.com/asset-inventory/docs/resource-name-format)
+                of a resource of `supported resource
+                types <https://cloud.google.com/asset-inventory/docs/supported-asset-types#analyzable_asset_types>`__.
+        """
+
+        full_resource_name = proto.Field(proto.STRING, number=1)
+
+    class IdentitySelector(proto.Message):
+        r"""Specifies an identity for which to determine resource access,
+        based on roles assigned either directly to them or to the groups
+        they belong to, directly or indirectly.
+
+        Attributes:
+            identity (str):
+                Required. The identity appear in the form of members in `IAM
+                policy
+                binding <https://cloud.google.com/iam/reference/rest/v1/Binding>`__.
+
+                The examples of supported forms are:
+                "user:mike@example.com", "group:admins@example.com",
+                "domain:google.com",
+                "serviceAccount:my-project-id@appspot.gserviceaccount.com".
+
+                Notice that wildcard characters (such as \* and ?) are not
+                supported. You must give a specific identity.
+        """
+
+        identity = proto.Field(proto.STRING, number=1)
+
+    class AccessSelector(proto.Message):
+        r"""Specifies roles and/or permissions to analyze, to determine
+        both the identities possessing them and the resources they
+        control. If multiple values are specified, results will include
+        roles or permissions matching any of them. The total number of
+        roles and permissions should be equal or less than 10.
+
+        Attributes:
+            roles (Sequence[str]):
+                Optional. The roles to appear in result.
+            permissions (Sequence[str]):
+                Optional. The permissions to appear in
+                result.
+        """
+
+        roles = proto.RepeatedField(proto.STRING, number=1)
+
+        permissions = proto.RepeatedField(proto.STRING, number=2)
+
+    class Options(proto.Message):
+        r"""Contains query options.
+
+        Attributes:
+            expand_groups (bool):
+                Optional. If true, the identities section of the result will
+                expand any Google groups appearing in an IAM policy binding.
+
+                If
+                [IamPolicyAnalysisQuery.identity_selector][google.cloud.asset.v1.IamPolicyAnalysisQuery.identity_selector]
+                is specified, the identity in the result will be determined
+                by the selector, and this flag is not allowed to set.
+
+                Default is false.
+            expand_roles (bool):
+                Optional. If true, the access section of result will expand
+                any roles appearing in IAM policy bindings to include their
+                permissions.
+
+                If
+                [IamPolicyAnalysisQuery.access_selector][google.cloud.asset.v1.IamPolicyAnalysisQuery.access_selector]
+                is specified, the access section of the result will be
+                determined by the selector, and this flag is not allowed to
+                set.
+
+                Default is false.
+            expand_resources (bool):
+                Optional. If true and
+                [IamPolicyAnalysisQuery.resource_selector][google.cloud.asset.v1.IamPolicyAnalysisQuery.resource_selector]
+                is not specified, the resource section of the result will
+                expand any resource attached to an IAM policy to include
+                resources lower in the resource hierarchy.
+
+                For example, if the request analyzes for which resources
+                user A has permission P, and the results include an IAM
+                policy with P on a GCP folder, the results will also include
+                resources in that folder with permission P.
+
+                If true and
+                [IamPolicyAnalysisQuery.resource_selector][google.cloud.asset.v1.IamPolicyAnalysisQuery.resource_selector]
+                is specified, the resource section of the result will expand
+                the specified resource to include resources lower in the
+                resource hierarchy. Only project or lower resources are
+                supported. Folder and organization resource cannot be used
+                together with this option.
+
+                For example, if the request analyzes for which users have
+                permission P on a GCP project with this option enabled, the
+                results will include all users who have permission P on that
+                project or any lower resource.
+
+                Default is false.
+            output_resource_edges (bool):
+                Optional. If true, the result will output
+                resource edges, starting from the policy
+                attached resource, to any expanded resources.
+                Default is false.
+            output_group_edges (bool):
+                Optional. If true, the result will output
+                group identity edges, starting from the
+                binding's group members, to any expanded
+                identities. Default is false.
+            analyze_service_account_impersonation (bool):
+                Optional. If true, the response will include access analysis
+                from identities to resources via service account
+                impersonation. This is a very expensive operation, because
+                many derived queries will be executed. We highly recommend
+                you use
+                [AssetService.AnalyzeIamPolicyLongrunning][google.cloud.asset.v1.AssetService.AnalyzeIamPolicyLongrunning]
+                rpc instead.
+
+                For example, if the request analyzes for which resources
+                user A has permission P, and there's an IAM policy states
+                user A has iam.serviceAccounts.getAccessToken permission to
+                a service account SA, and there's another IAM policy states
+                service account SA has permission P to a GCP folder F, then
+                user A potentially has access to the GCP folder F. And those
+                advanced analysis results will be included in
+                [AnalyzeIamPolicyResponse.service_account_impersonation_analysis][google.cloud.asset.v1.AnalyzeIamPolicyResponse.service_account_impersonation_analysis].
+
+                Another example, if the request analyzes for who has
+                permission P to a GCP folder F, and there's an IAM policy
+                states user A has iam.serviceAccounts.actAs permission to a
+                service account SA, and there's another IAM policy states
+                service account SA has permission P to the GCP folder F,
+                then user A potentially has access to the GCP folder F. And
+                those advanced analysis results will be included in
+                [AnalyzeIamPolicyResponse.service_account_impersonation_analysis][google.cloud.asset.v1.AnalyzeIamPolicyResponse.service_account_impersonation_analysis].
+
+                Default is false.
+        """
+
+        expand_groups = proto.Field(proto.BOOL, number=1)
+
+        expand_roles = proto.Field(proto.BOOL, number=2)
+
+        expand_resources = proto.Field(proto.BOOL, number=3)
+
+        output_resource_edges = proto.Field(proto.BOOL, number=4)
+
+        output_group_edges = proto.Field(proto.BOOL, number=5)
+
+        analyze_service_account_impersonation = proto.Field(proto.BOOL, number=6)
+
+    scope = proto.Field(proto.STRING, number=1)
+
+    resource_selector = proto.Field(proto.MESSAGE, number=2, message=ResourceSelector,)
+
+    identity_selector = proto.Field(proto.MESSAGE, number=3, message=IdentitySelector,)
+
+    access_selector = proto.Field(proto.MESSAGE, number=4, message=AccessSelector,)
+
+    options = proto.Field(proto.MESSAGE, number=5, message=Options,)
+
+
+class AnalyzeIamPolicyRequest(proto.Message):
+    r"""A request message for
+    [AssetService.AnalyzeIamPolicy][google.cloud.asset.v1.AssetService.AnalyzeIamPolicy].
+
+    Attributes:
+        analysis_query (~.asset_service.IamPolicyAnalysisQuery):
+            Required. The request query.
+        execution_timeout (~.duration.Duration):
+            Optional. Amount of time executable has to complete. See
+            JSON representation of
+            `Duration <https://developers.google.com/protocol-buffers/docs/proto3#json>`__.
+
+            If this field is set with a value less than the RPC
+            deadline, and the execution of your query hasn't finished in
+            the specified execution timeout, you will get a response
+            with partial result. Otherwise, your query's execution will
+            continue until the RPC deadline. If it's not finished until
+            then, you will get a DEADLINE_EXCEEDED error.
+
+            Default is empty.
+    """
+
+    analysis_query = proto.Field(
+        proto.MESSAGE, number=1, message="IamPolicyAnalysisQuery",
+    )
+
+    execution_timeout = proto.Field(proto.MESSAGE, number=2, message=duration.Duration,)
+
+
+class AnalyzeIamPolicyResponse(proto.Message):
+    r"""A response message for
+    [AssetService.AnalyzeIamPolicy][google.cloud.asset.v1.AssetService.AnalyzeIamPolicy].
+
+    Attributes:
+        main_analysis (~.asset_service.AnalyzeIamPolicyResponse.IamPolicyAnalysis):
+            The main analysis that matches the original
+            request.
+        service_account_impersonation_analysis (Sequence[~.asset_service.AnalyzeIamPolicyResponse.IamPolicyAnalysis]):
+            The service account impersonation analysis if
+            [AnalyzeIamPolicyRequest.analyze_service_account_impersonation][]
+            is enabled.
+        fully_explored (bool):
+            Represents whether all entries in the
+            [main_analysis][google.cloud.asset.v1.AnalyzeIamPolicyResponse.main_analysis]
+            and
+            [service_account_impersonation_analysis][google.cloud.asset.v1.AnalyzeIamPolicyResponse.service_account_impersonation_analysis]
+            have been fully explored to answer the query in the request.
+    """
+
+    class IamPolicyAnalysis(proto.Message):
+        r"""An analysis message to group the query and results.
+
+        Attributes:
+            analysis_query (~.asset_service.IamPolicyAnalysisQuery):
+                The analysis query.
+            analysis_results (Sequence[~.gca_assets.IamPolicyAnalysisResult]):
+                A list of
+                [IamPolicyAnalysisResult][google.cloud.asset.v1.IamPolicyAnalysisResult]
+                that matches the analysis query, or empty if no result is
+                found.
+            fully_explored (bool):
+                Represents whether all entries in the
+                [analysis_results][google.cloud.asset.v1.AnalyzeIamPolicyResponse.IamPolicyAnalysis.analysis_results]
+                have been fully explored to answer the query.
+            non_critical_errors (Sequence[~.gca_assets.IamPolicyAnalysisState]):
+                A list of non-critical errors happened during
+                the query handling.
+        """
+
+        analysis_query = proto.Field(
+            proto.MESSAGE, number=1, message="IamPolicyAnalysisQuery",
+        )
+
+        analysis_results = proto.RepeatedField(
+            proto.MESSAGE, number=2, message=gca_assets.IamPolicyAnalysisResult,
+        )
+
+        fully_explored = proto.Field(proto.BOOL, number=3)
+
+        non_critical_errors = proto.RepeatedField(
+            proto.MESSAGE, number=5, message=gca_assets.IamPolicyAnalysisState,
+        )
+
+    main_analysis = proto.Field(proto.MESSAGE, number=1, message=IamPolicyAnalysis,)
+
+    service_account_impersonation_analysis = proto.RepeatedField(
+        proto.MESSAGE, number=2, message=IamPolicyAnalysis,
+    )
+
+    fully_explored = proto.Field(proto.BOOL, number=3)
+
+
+class IamPolicyAnalysisOutputConfig(proto.Message):
+    r"""Output configuration for export IAM policy analysis
+    destination.
+
+    Attributes:
+        gcs_destination (~.asset_service.IamPolicyAnalysisOutputConfig.GcsDestination):
+            Destination on Cloud Storage.
+        bigquery_destination (~.asset_service.IamPolicyAnalysisOutputConfig.BigQueryDestination):
+            Destination on BigQuery.
+    """
+
+    class GcsDestination(proto.Message):
+        r"""A Cloud Storage location.
+
+        Attributes:
+            uri (str):
+                Required. The uri of the Cloud Storage object. It's the same
+                uri that is used by gsutil. For example:
+                "gs://bucket_name/object_name". See [Quickstart: Using the
+                gsutil tool]
+                (https://cloud.google.com/storage/docs/quickstart-gsutil)
+                for examples.
+        """
+
+        uri = proto.Field(proto.STRING, number=1)
+
+    class BigQueryDestination(proto.Message):
+        r"""A BigQuery destination.
+
+        Attributes:
+            dataset (str):
+                Required. The BigQuery dataset in format
+                "projects/projectId/datasets/datasetId", to which the
+                analysis results should be exported. If this dataset does
+                not exist, the export call will return an INVALID_ARGUMENT
+                error.
+            table_prefix (str):
+                Required. The prefix of the BigQuery tables to which the
+                analysis results will be written. Tables will be created
+                based on this table_prefix if not exist:
+
+                -  <table_prefix>_analysis table will contain export
+                   operation's metadata.
+                -  <table_prefix>_analysis_result will contain all the
+                   [IamPolicyAnalysisResult][google.cloud.asset.v1.IamPolicyAnalysisResult].
+                   When [partition_key] is specified, both tables will be
+                   partitioned based on the [partition_key].
+            partition_key (~.asset_service.IamPolicyAnalysisOutputConfig.BigQueryDestination.PartitionKey):
+                The partition key for BigQuery partitioned
+                table.
+            write_disposition (str):
+                Optional. Specifies the action that occurs if the
+                destination table or partition already exists. The following
+                values are supported:
+
+                -  WRITE_TRUNCATE: If the table or partition already exists,
+                   BigQuery overwrites the entire table or all the
+                   partitions data.
+                -  WRITE_APPEND: If the table or partition already exists,
+                   BigQuery appends the data to the table or the latest
+                   partition.
+                -  WRITE_EMPTY: If the table already exists and contains
+                   data, an error is returned.
+
+                The default value is WRITE_APPEND. Each action is atomic and
+                only occurs if BigQuery is able to complete the job
+                successfully. Details are at
+                https://cloud.google.com/bigquery/docs/loading-data-local#appending_to_or_overwriting_a_table_using_a_local_file.
+        """
+
+        class PartitionKey(proto.Enum):
+            r"""This enum determines the partition key column for the
+            bigquery tables. Partitioning can improve query performance and
+            reduce query cost by filtering partitions. Refer to
+            https://cloud.google.com/bigquery/docs/partitioned-tables for
+            details.
+            """
+            PARTITION_KEY_UNSPECIFIED = 0
+            REQUEST_TIME = 1
+
+        dataset = proto.Field(proto.STRING, number=1)
+
+        table_prefix = proto.Field(proto.STRING, number=2)
+
+        partition_key = proto.Field(
+            proto.ENUM,
+            number=3,
+            enum="IamPolicyAnalysisOutputConfig.BigQueryDestination.PartitionKey",
+        )
+
+        write_disposition = proto.Field(proto.STRING, number=4)
+
+    gcs_destination = proto.Field(
+        proto.MESSAGE, number=1, oneof="destination", message=GcsDestination,
+    )
+
+    bigquery_destination = proto.Field(
+        proto.MESSAGE, number=2, oneof="destination", message=BigQueryDestination,
+    )
+
+
+class AnalyzeIamPolicyLongrunningRequest(proto.Message):
+    r"""A request message for
+    [AssetService.AnalyzeIamPolicyLongrunning][google.cloud.asset.v1.AssetService.AnalyzeIamPolicyLongrunning].
+
+    Attributes:
+        analysis_query (~.asset_service.IamPolicyAnalysisQuery):
+            Required. The request query.
+        output_config (~.asset_service.IamPolicyAnalysisOutputConfig):
+            Required. Output configuration indicating
+            where the results will be output to.
+    """
+
+    analysis_query = proto.Field(
+        proto.MESSAGE, number=1, message="IamPolicyAnalysisQuery",
+    )
+
+    output_config = proto.Field(
+        proto.MESSAGE, number=2, message="IamPolicyAnalysisOutputConfig",
+    )
+
+
+class AnalyzeIamPolicyLongrunningResponse(proto.Message):
+    r"""A response message for
+    [AssetService.AnalyzeIamPolicyLongrunning][google.cloud.asset.v1.AssetService.AnalyzeIamPolicyLongrunning].
+    """
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
