@@ -46,9 +46,43 @@ class AssetServiceAsyncClient:
     feed_path = staticmethod(AssetServiceClient.feed_path)
     parse_feed_path = staticmethod(AssetServiceClient.parse_feed_path)
 
+    common_billing_account_path = staticmethod(
+        AssetServiceClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        AssetServiceClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(AssetServiceClient.common_folder_path)
+    parse_common_folder_path = staticmethod(AssetServiceClient.parse_common_folder_path)
+
+    common_organization_path = staticmethod(AssetServiceClient.common_organization_path)
+    parse_common_organization_path = staticmethod(
+        AssetServiceClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(AssetServiceClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        AssetServiceClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(AssetServiceClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        AssetServiceClient.parse_common_location_path
+    )
+
     from_service_account_file = AssetServiceClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> AssetServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            AssetServiceTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(AssetServiceClient).get_transport_class, type(AssetServiceClient)
     )
@@ -151,7 +185,8 @@ class AssetServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -228,7 +263,8 @@ class AssetServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -251,7 +287,7 @@ class AssetServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
             ),
             default_timeout=60.0,
@@ -309,7 +345,8 @@ class AssetServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -332,7 +369,7 @@ class AssetServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
             ),
             default_timeout=60.0,
@@ -395,7 +432,8 @@ class AssetServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([feed]):
+        has_flattened_params = any([feed])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -463,7 +501,8 @@ class AssetServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -486,7 +525,7 @@ class AssetServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
             ),
             default_timeout=60.0,
