@@ -90,12 +90,12 @@ def test_asset_service_client_from_service_account_file(client_class):
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
         client = client_class.from_service_account_json("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
-        assert client._transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_client_get_transport_class():
@@ -440,7 +440,7 @@ def test_search_all_resources(
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.SearchAllResourcesResponse(
@@ -456,6 +456,7 @@ def test_search_all_resources(
         assert args[0] == asset_service.SearchAllResourcesRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, pagers.SearchAllResourcesPager)
 
     assert response.next_page_token == "next_page_token_value"
@@ -466,18 +467,21 @@ def test_search_all_resources_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_search_all_resources_async(transport: str = "grpc_asyncio"):
+async def test_search_all_resources_async(
+    transport: str = "grpc_asyncio",
+    request_type=asset_service.SearchAllResourcesRequest,
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.SearchAllResourcesRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
@@ -492,7 +496,7 @@ async def test_search_all_resources_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.SearchAllResourcesRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, pagers.SearchAllResourcesAsyncPager)
@@ -500,6 +504,11 @@ async def test_search_all_resources_async(transport: str = "grpc_asyncio"):
     assert response.next_page_token == "next_page_token_value"
 
 
+@pytest.mark.asyncio
+async def test_search_all_resources_async_from_dict():
+    await test_search_all_resources_async(request_type=dict)
+
+
 def test_search_all_resources_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -510,7 +519,7 @@ def test_search_all_resources_field_headers():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         call.return_value = asset_service.SearchAllResourcesResponse()
 
@@ -537,7 +546,7 @@ async def test_search_all_resources_field_headers_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.SearchAllResourcesResponse()
@@ -560,7 +569,7 @@ def test_search_all_resources_flattened():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.SearchAllResourcesResponse()
@@ -603,7 +612,7 @@ async def test_search_all_resources_flattened_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.SearchAllResourcesResponse()
@@ -649,7 +658,7 @@ def test_search_all_resources_pager():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -694,7 +703,7 @@ def test_search_all_resources_pages():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_resources), "__call__"
+        type(client.transport.search_all_resources), "__call__"
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -731,7 +740,7 @@ async def test_search_all_resources_async_pager():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_resources),
+        type(client.transport.search_all_resources),
         "__call__",
         new_callable=mock.AsyncMock,
     ) as call:
@@ -775,7 +784,7 @@ async def test_search_all_resources_async_pages():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_resources),
+        type(client.transport.search_all_resources),
         "__call__",
         new_callable=mock.AsyncMock,
     ) as call:
@@ -823,7 +832,7 @@ def test_search_all_iam_policies(
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.SearchAllIamPoliciesResponse(
@@ -839,6 +848,7 @@ def test_search_all_iam_policies(
         assert args[0] == asset_service.SearchAllIamPoliciesRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, pagers.SearchAllIamPoliciesPager)
 
     assert response.next_page_token == "next_page_token_value"
@@ -849,18 +859,21 @@ def test_search_all_iam_policies_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_search_all_iam_policies_async(transport: str = "grpc_asyncio"):
+async def test_search_all_iam_policies_async(
+    transport: str = "grpc_asyncio",
+    request_type=asset_service.SearchAllIamPoliciesRequest,
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.SearchAllIamPoliciesRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
@@ -875,7 +888,7 @@ async def test_search_all_iam_policies_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.SearchAllIamPoliciesRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, pagers.SearchAllIamPoliciesAsyncPager)
@@ -883,6 +896,11 @@ async def test_search_all_iam_policies_async(transport: str = "grpc_asyncio"):
     assert response.next_page_token == "next_page_token_value"
 
 
+@pytest.mark.asyncio
+async def test_search_all_iam_policies_async_from_dict():
+    await test_search_all_iam_policies_async(request_type=dict)
+
+
 def test_search_all_iam_policies_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -893,7 +911,7 @@ def test_search_all_iam_policies_field_headers():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         call.return_value = asset_service.SearchAllIamPoliciesResponse()
 
@@ -920,7 +938,7 @@ async def test_search_all_iam_policies_field_headers_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.SearchAllIamPoliciesResponse()
@@ -943,7 +961,7 @@ def test_search_all_iam_policies_flattened():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.SearchAllIamPoliciesResponse()
@@ -983,7 +1001,7 @@ async def test_search_all_iam_policies_flattened_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.SearchAllIamPoliciesResponse()
@@ -1026,7 +1044,7 @@ def test_search_all_iam_policies_pager():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -1071,7 +1089,7 @@ def test_search_all_iam_policies_pages():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.search_all_iam_policies), "__call__"
+        type(client.transport.search_all_iam_policies), "__call__"
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -1108,7 +1126,7 @@ async def test_search_all_iam_policies_async_pager():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_iam_policies),
+        type(client.transport.search_all_iam_policies),
         "__call__",
         new_callable=mock.AsyncMock,
     ) as call:
@@ -1152,7 +1170,7 @@ async def test_search_all_iam_policies_async_pages():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.search_all_iam_policies),
+        type(client.transport.search_all_iam_policies),
         "__call__",
         new_callable=mock.AsyncMock,
     ) as call:
@@ -1223,7 +1241,7 @@ def test_transport_instance():
         credentials=credentials.AnonymousCredentials(),
     )
     client = AssetServiceClient(transport=transport)
-    assert client._transport is transport
+    assert client.transport is transport
 
 
 def test_transport_get_channel():
@@ -1256,7 +1274,7 @@ def test_transport_adc(transport_class):
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client._transport, transports.AssetServiceGrpcTransport,)
+    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
 
 
 def test_asset_service_base_transport_error():
@@ -1351,7 +1369,7 @@ def test_asset_service_host_no_port():
             api_endpoint="cloudasset.googleapis.com"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:443"
+    assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_host_with_port():
@@ -1361,7 +1379,7 @@ def test_asset_service_host_with_port():
             api_endpoint="cloudasset.googleapis.com:8000"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:8000"
+    assert client.transport._host == "cloudasset.googleapis.com:8000"
 
 
 def test_asset_service_grpc_transport_channel():
@@ -1373,6 +1391,7 @@ def test_asset_service_grpc_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 def test_asset_service_grpc_asyncio_transport_channel():
@@ -1384,6 +1403,7 @@ def test_asset_service_grpc_asyncio_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 @pytest.mark.parametrize(
@@ -1426,6 +1446,7 @@ def test_asset_service_transport_channel_mtls_with_client_cert_source(transport_
                 quota_project_id=None,
             )
             assert transport.grpc_channel == mock_grpc_channel
+            assert transport._ssl_channel_credentials == mock_ssl_cred
 
 
 @pytest.mark.parametrize(
@@ -1465,6 +1486,107 @@ def test_asset_service_transport_channel_mtls_with_adc(transport_class):
             assert transport.grpc_channel == mock_grpc_channel
 
 
+def test_common_billing_account_path():
+    billing_account = "squid"
+
+    expected = "billingAccounts/{billing_account}".format(
+        billing_account=billing_account,
+    )
+    actual = AssetServiceClient.common_billing_account_path(billing_account)
+    assert expected == actual
+
+
+def test_parse_common_billing_account_path():
+    expected = {
+        "billing_account": "clam",
+    }
+    path = AssetServiceClient.common_billing_account_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_billing_account_path(path)
+    assert expected == actual
+
+
+def test_common_folder_path():
+    folder = "whelk"
+
+    expected = "folders/{folder}".format(folder=folder,)
+    actual = AssetServiceClient.common_folder_path(folder)
+    assert expected == actual
+
+
+def test_parse_common_folder_path():
+    expected = {
+        "folder": "octopus",
+    }
+    path = AssetServiceClient.common_folder_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_folder_path(path)
+    assert expected == actual
+
+
+def test_common_organization_path():
+    organization = "oyster"
+
+    expected = "organizations/{organization}".format(organization=organization,)
+    actual = AssetServiceClient.common_organization_path(organization)
+    assert expected == actual
+
+
+def test_parse_common_organization_path():
+    expected = {
+        "organization": "nudibranch",
+    }
+    path = AssetServiceClient.common_organization_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_organization_path(path)
+    assert expected == actual
+
+
+def test_common_project_path():
+    project = "cuttlefish"
+
+    expected = "projects/{project}".format(project=project,)
+    actual = AssetServiceClient.common_project_path(project)
+    assert expected == actual
+
+
+def test_parse_common_project_path():
+    expected = {
+        "project": "mussel",
+    }
+    path = AssetServiceClient.common_project_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_project_path(path)
+    assert expected == actual
+
+
+def test_common_location_path():
+    project = "winkle"
+    location = "nautilus"
+
+    expected = "projects/{project}/locations/{location}".format(
+        project=project, location=location,
+    )
+    actual = AssetServiceClient.common_location_path(project, location)
+    assert expected == actual
+
+
+def test_parse_common_location_path():
+    expected = {
+        "project": "scallop",
+        "location": "abalone",
+    }
+    path = AssetServiceClient.common_location_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_location_path(path)
+    assert expected == actual
+
+
 def test_client_withDEFAULT_CLIENT_INFO():
     client_info = gapic_v1.client_info.ClientInfo()
 
