@@ -89,12 +89,12 @@ def test_asset_service_client_from_service_account_file(client_class):
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
         client = client_class.from_service_account_json("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
-        assert client._transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_client_get_transport_class():
@@ -438,7 +438,7 @@ def test_create_feed(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.create_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.create_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed(
             name="name_value",
@@ -456,6 +456,7 @@ def test_create_feed(
         assert args[0] == asset_service.CreateFeedRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, asset_service.Feed)
 
     assert response.name == "name_value"
@@ -472,19 +473,19 @@ def test_create_feed_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_create_feed_async(transport: str = "grpc_asyncio"):
+async def test_create_feed_async(
+    transport: str = "grpc_asyncio", request_type=asset_service.CreateFeedRequest
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.CreateFeedRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.create_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.Feed(
@@ -501,7 +502,7 @@ async def test_create_feed_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.CreateFeedRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, asset_service.Feed)
@@ -515,6 +516,11 @@ async def test_create_feed_async(transport: str = "grpc_asyncio"):
     assert response.content_type == asset_service.ContentType.RESOURCE
 
 
+@pytest.mark.asyncio
+async def test_create_feed_async_from_dict():
+    await test_create_feed_async(request_type=dict)
+
+
 def test_create_feed_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -524,7 +530,7 @@ def test_create_feed_field_headers():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.create_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.create_feed), "__call__") as call:
         call.return_value = asset_service.Feed()
 
         client.create_feed(request)
@@ -549,9 +555,7 @@ async def test_create_feed_field_headers_async():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.create_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_feed), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(asset_service.Feed())
 
         await client.create_feed(request)
@@ -570,7 +574,7 @@ def test_create_feed_flattened():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.create_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.create_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed()
 
@@ -602,9 +606,7 @@ async def test_create_feed_flattened_async():
     client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.create_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed()
 
@@ -643,7 +645,7 @@ def test_get_feed(transport: str = "grpc", request_type=asset_service.GetFeedReq
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.get_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.get_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed(
             name="name_value",
@@ -661,6 +663,7 @@ def test_get_feed(transport: str = "grpc", request_type=asset_service.GetFeedReq
         assert args[0] == asset_service.GetFeedRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, asset_service.Feed)
 
     assert response.name == "name_value"
@@ -677,19 +680,19 @@ def test_get_feed_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_get_feed_async(transport: str = "grpc_asyncio"):
+async def test_get_feed_async(
+    transport: str = "grpc_asyncio", request_type=asset_service.GetFeedRequest
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.GetFeedRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.get_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.get_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.Feed(
@@ -706,7 +709,7 @@ async def test_get_feed_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.GetFeedRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, asset_service.Feed)
@@ -720,6 +723,11 @@ async def test_get_feed_async(transport: str = "grpc_asyncio"):
     assert response.content_type == asset_service.ContentType.RESOURCE
 
 
+@pytest.mark.asyncio
+async def test_get_feed_async_from_dict():
+    await test_get_feed_async(request_type=dict)
+
+
 def test_get_feed_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -729,7 +737,7 @@ def test_get_feed_field_headers():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.get_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.get_feed), "__call__") as call:
         call.return_value = asset_service.Feed()
 
         client.get_feed(request)
@@ -754,9 +762,7 @@ async def test_get_feed_field_headers_async():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.get_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.get_feed), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(asset_service.Feed())
 
         await client.get_feed(request)
@@ -775,7 +781,7 @@ def test_get_feed_flattened():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.get_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.get_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed()
 
@@ -807,9 +813,7 @@ async def test_get_feed_flattened_async():
     client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.get_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.get_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed()
 
@@ -850,7 +854,7 @@ def test_list_feeds(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_feeds), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_feeds), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.ListFeedsResponse()
 
@@ -863,6 +867,7 @@ def test_list_feeds(
         assert args[0] == asset_service.ListFeedsRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, asset_service.ListFeedsResponse)
 
 
@@ -871,19 +876,19 @@ def test_list_feeds_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_list_feeds_async(transport: str = "grpc_asyncio"):
+async def test_list_feeds_async(
+    transport: str = "grpc_asyncio", request_type=asset_service.ListFeedsRequest
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.ListFeedsRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_feeds), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_feeds), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.ListFeedsResponse()
@@ -895,12 +900,17 @@ async def test_list_feeds_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.ListFeedsRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, asset_service.ListFeedsResponse)
 
 
+@pytest.mark.asyncio
+async def test_list_feeds_async_from_dict():
+    await test_list_feeds_async(request_type=dict)
+
+
 def test_list_feeds_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -910,7 +920,7 @@ def test_list_feeds_field_headers():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_feeds), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_feeds), "__call__") as call:
         call.return_value = asset_service.ListFeedsResponse()
 
         client.list_feeds(request)
@@ -935,9 +945,7 @@ async def test_list_feeds_field_headers_async():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_feeds), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_feeds), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.ListFeedsResponse()
         )
@@ -958,7 +966,7 @@ def test_list_feeds_flattened():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_feeds), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_feeds), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.ListFeedsResponse()
 
@@ -990,9 +998,7 @@ async def test_list_feeds_flattened_async():
     client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_feeds), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_feeds), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.ListFeedsResponse()
 
@@ -1035,7 +1041,7 @@ def test_update_feed(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.update_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.update_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed(
             name="name_value",
@@ -1053,6 +1059,7 @@ def test_update_feed(
         assert args[0] == asset_service.UpdateFeedRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, asset_service.Feed)
 
     assert response.name == "name_value"
@@ -1069,19 +1076,19 @@ def test_update_feed_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_update_feed_async(transport: str = "grpc_asyncio"):
+async def test_update_feed_async(
+    transport: str = "grpc_asyncio", request_type=asset_service.UpdateFeedRequest
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.UpdateFeedRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.update_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.update_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.Feed(
@@ -1098,7 +1105,7 @@ async def test_update_feed_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.UpdateFeedRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, asset_service.Feed)
@@ -1112,6 +1119,11 @@ async def test_update_feed_async(transport: str = "grpc_asyncio"):
     assert response.content_type == asset_service.ContentType.RESOURCE
 
 
+@pytest.mark.asyncio
+async def test_update_feed_async_from_dict():
+    await test_update_feed_async(request_type=dict)
+
+
 def test_update_feed_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -1121,7 +1133,7 @@ def test_update_feed_field_headers():
     request.feed.name = "feed.name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.update_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.update_feed), "__call__") as call:
         call.return_value = asset_service.Feed()
 
         client.update_feed(request)
@@ -1146,9 +1158,7 @@ async def test_update_feed_field_headers_async():
     request.feed.name = "feed.name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.update_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.update_feed), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(asset_service.Feed())
 
         await client.update_feed(request)
@@ -1167,7 +1177,7 @@ def test_update_feed_flattened():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.update_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.update_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed()
 
@@ -1200,9 +1210,7 @@ async def test_update_feed_flattened_async():
     client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.update_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.update_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.Feed()
 
@@ -1244,7 +1252,7 @@ def test_delete_feed(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.delete_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.delete_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = None
 
@@ -1265,19 +1273,19 @@ def test_delete_feed_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_delete_feed_async(transport: str = "grpc_asyncio"):
+async def test_delete_feed_async(
+    transport: str = "grpc_asyncio", request_type=asset_service.DeleteFeedRequest
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.DeleteFeedRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.delete_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.delete_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(None)
 
@@ -1287,12 +1295,17 @@ async def test_delete_feed_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.DeleteFeedRequest()
 
     # Establish that the response is the type that we expect.
     assert response is None
 
 
+@pytest.mark.asyncio
+async def test_delete_feed_async_from_dict():
+    await test_delete_feed_async(request_type=dict)
+
+
 def test_delete_feed_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -1302,7 +1315,7 @@ def test_delete_feed_field_headers():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.delete_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.delete_feed), "__call__") as call:
         call.return_value = None
 
         client.delete_feed(request)
@@ -1327,9 +1340,7 @@ async def test_delete_feed_field_headers_async():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.delete_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.delete_feed), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(None)
 
         await client.delete_feed(request)
@@ -1348,7 +1359,7 @@ def test_delete_feed_flattened():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.delete_feed), "__call__") as call:
+    with mock.patch.object(type(client.transport.delete_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = None
 
@@ -1380,9 +1391,7 @@ async def test_delete_feed_flattened_async():
     client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.delete_feed), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.delete_feed), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = None
 
@@ -1447,7 +1456,7 @@ def test_transport_instance():
         credentials=credentials.AnonymousCredentials(),
     )
     client = AssetServiceClient(transport=transport)
-    assert client._transport is transport
+    assert client.transport is transport
 
 
 def test_transport_get_channel():
@@ -1480,7 +1489,7 @@ def test_transport_adc(transport_class):
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client._transport, transports.AssetServiceGrpcTransport,)
+    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
 
 
 def test_asset_service_base_transport_error():
@@ -1578,7 +1587,7 @@ def test_asset_service_host_no_port():
             api_endpoint="cloudasset.googleapis.com"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:443"
+    assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_host_with_port():
@@ -1588,7 +1597,7 @@ def test_asset_service_host_with_port():
             api_endpoint="cloudasset.googleapis.com:8000"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:8000"
+    assert client.transport._host == "cloudasset.googleapis.com:8000"
 
 
 def test_asset_service_grpc_transport_channel():
@@ -1600,6 +1609,7 @@ def test_asset_service_grpc_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 def test_asset_service_grpc_asyncio_transport_channel():
@@ -1611,6 +1621,7 @@ def test_asset_service_grpc_asyncio_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 @pytest.mark.parametrize(
@@ -1653,6 +1664,7 @@ def test_asset_service_transport_channel_mtls_with_client_cert_source(transport_
                 quota_project_id=None,
             )
             assert transport.grpc_channel == mock_grpc_channel
+            assert transport._ssl_channel_credentials == mock_ssl_cred
 
 
 @pytest.mark.parametrize(
@@ -1713,6 +1725,107 @@ def test_parse_feed_path():
     assert expected == actual
 
 
+def test_common_billing_account_path():
+    billing_account = "oyster"
+
+    expected = "billingAccounts/{billing_account}".format(
+        billing_account=billing_account,
+    )
+    actual = AssetServiceClient.common_billing_account_path(billing_account)
+    assert expected == actual
+
+
+def test_parse_common_billing_account_path():
+    expected = {
+        "billing_account": "nudibranch",
+    }
+    path = AssetServiceClient.common_billing_account_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_billing_account_path(path)
+    assert expected == actual
+
+
+def test_common_folder_path():
+    folder = "cuttlefish"
+
+    expected = "folders/{folder}".format(folder=folder,)
+    actual = AssetServiceClient.common_folder_path(folder)
+    assert expected == actual
+
+
+def test_parse_common_folder_path():
+    expected = {
+        "folder": "mussel",
+    }
+    path = AssetServiceClient.common_folder_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_folder_path(path)
+    assert expected == actual
+
+
+def test_common_organization_path():
+    organization = "winkle"
+
+    expected = "organizations/{organization}".format(organization=organization,)
+    actual = AssetServiceClient.common_organization_path(organization)
+    assert expected == actual
+
+
+def test_parse_common_organization_path():
+    expected = {
+        "organization": "nautilus",
+    }
+    path = AssetServiceClient.common_organization_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_organization_path(path)
+    assert expected == actual
+
+
+def test_common_project_path():
+    project = "scallop"
+
+    expected = "projects/{project}".format(project=project,)
+    actual = AssetServiceClient.common_project_path(project)
+    assert expected == actual
+
+
+def test_parse_common_project_path():
+    expected = {
+        "project": "abalone",
+    }
+    path = AssetServiceClient.common_project_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_project_path(path)
+    assert expected == actual
+
+
+def test_common_location_path():
+    project = "squid"
+    location = "clam"
+
+    expected = "projects/{project}/locations/{location}".format(
+        project=project, location=location,
+    )
+    actual = AssetServiceClient.common_location_path(project, location)
+    assert expected == actual
+
+
+def test_parse_common_location_path():
+    expected = {
+        "project": "whelk",
+        "location": "octopus",
+    }
+    path = AssetServiceClient.common_location_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_location_path(path)
+    assert expected == actual
+
+
 def test_client_withDEFAULT_CLIENT_INFO():
     client_info = gapic_v1.client_info.ClientInfo()
 
