@@ -94,12 +94,12 @@ def test_asset_service_client_from_service_account_file(client_class):
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
         client = client_class.from_service_account_json("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
-        assert client._transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_client_get_transport_class():
@@ -444,7 +444,7 @@ def test_analyze_iam_policy(
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.analyze_iam_policy), "__call__"
+        type(client.transport.analyze_iam_policy), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.AnalyzeIamPolicyResponse(fully_explored=True,)
@@ -458,6 +458,7 @@ def test_analyze_iam_policy(
         assert args[0] == asset_service.AnalyzeIamPolicyRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, asset_service.AnalyzeIamPolicyResponse)
 
     assert response.fully_explored is True
@@ -468,18 +469,20 @@ def test_analyze_iam_policy_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_analyze_iam_policy_async(transport: str = "grpc_asyncio"):
+async def test_analyze_iam_policy_async(
+    transport: str = "grpc_asyncio", request_type=asset_service.AnalyzeIamPolicyRequest
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.AnalyzeIamPolicyRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.analyze_iam_policy), "__call__"
+        type(client.transport.analyze_iam_policy), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
@@ -492,7 +495,7 @@ async def test_analyze_iam_policy_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.AnalyzeIamPolicyRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, asset_service.AnalyzeIamPolicyResponse)
@@ -500,6 +503,11 @@ async def test_analyze_iam_policy_async(transport: str = "grpc_asyncio"):
     assert response.fully_explored is True
 
 
+@pytest.mark.asyncio
+async def test_analyze_iam_policy_async_from_dict():
+    await test_analyze_iam_policy_async(request_type=dict)
+
+
 def test_analyze_iam_policy_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -510,7 +518,7 @@ def test_analyze_iam_policy_field_headers():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.analyze_iam_policy), "__call__"
+        type(client.transport.analyze_iam_policy), "__call__"
     ) as call:
         call.return_value = asset_service.AnalyzeIamPolicyResponse()
 
@@ -540,7 +548,7 @@ async def test_analyze_iam_policy_field_headers_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.analyze_iam_policy), "__call__"
+        type(client.transport.analyze_iam_policy), "__call__"
     ) as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.AnalyzeIamPolicyResponse()
@@ -574,7 +582,7 @@ def test_export_iam_policy_analysis(
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.export_iam_policy_analysis), "__call__"
+        type(client.transport.export_iam_policy_analysis), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/spam")
@@ -596,18 +604,21 @@ def test_export_iam_policy_analysis_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_export_iam_policy_analysis_async(transport: str = "grpc_asyncio"):
+async def test_export_iam_policy_analysis_async(
+    transport: str = "grpc_asyncio",
+    request_type=asset_service.ExportIamPolicyAnalysisRequest,
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.ExportIamPolicyAnalysisRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.export_iam_policy_analysis), "__call__"
+        type(client.transport.export_iam_policy_analysis), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
@@ -620,12 +631,17 @@ async def test_export_iam_policy_analysis_async(transport: str = "grpc_asyncio")
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.ExportIamPolicyAnalysisRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, future.Future)
 
 
+@pytest.mark.asyncio
+async def test_export_iam_policy_analysis_async_from_dict():
+    await test_export_iam_policy_analysis_async(request_type=dict)
+
+
 def test_export_iam_policy_analysis_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -636,7 +652,7 @@ def test_export_iam_policy_analysis_field_headers():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._transport.export_iam_policy_analysis), "__call__"
+        type(client.transport.export_iam_policy_analysis), "__call__"
     ) as call:
         call.return_value = operations_pb2.Operation(name="operations/op")
 
@@ -666,7 +682,7 @@ async def test_export_iam_policy_analysis_field_headers_async():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.export_iam_policy_analysis), "__call__"
+        type(client.transport.export_iam_policy_analysis), "__call__"
     ) as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/op")
@@ -723,7 +739,7 @@ def test_transport_instance():
         credentials=credentials.AnonymousCredentials(),
     )
     client = AssetServiceClient(transport=transport)
-    assert client._transport is transport
+    assert client.transport is transport
 
 
 def test_transport_get_channel():
@@ -756,7 +772,7 @@ def test_transport_adc(transport_class):
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client._transport, transports.AssetServiceGrpcTransport,)
+    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
 
 
 def test_asset_service_base_transport_error():
@@ -856,7 +872,7 @@ def test_asset_service_host_no_port():
             api_endpoint="cloudasset.googleapis.com"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:443"
+    assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_host_with_port():
@@ -866,7 +882,7 @@ def test_asset_service_host_with_port():
             api_endpoint="cloudasset.googleapis.com:8000"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:8000"
+    assert client.transport._host == "cloudasset.googleapis.com:8000"
 
 
 def test_asset_service_grpc_transport_channel():
@@ -878,6 +894,7 @@ def test_asset_service_grpc_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 def test_asset_service_grpc_asyncio_transport_channel():
@@ -889,6 +906,7 @@ def test_asset_service_grpc_asyncio_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 @pytest.mark.parametrize(
@@ -931,6 +949,7 @@ def test_asset_service_transport_channel_mtls_with_client_cert_source(transport_
                 quota_project_id=None,
             )
             assert transport.grpc_channel == mock_grpc_channel
+            assert transport._ssl_channel_credentials == mock_ssl_cred
 
 
 @pytest.mark.parametrize(
@@ -974,7 +993,7 @@ def test_asset_service_grpc_lro_client():
     client = AssetServiceClient(
         credentials=credentials.AnonymousCredentials(), transport="grpc",
     )
-    transport = client._transport
+    transport = client.transport
 
     # Ensure that we have a api-core operations client.
     assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
@@ -987,7 +1006,7 @@ def test_asset_service_grpc_lro_async_client():
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport="grpc_asyncio",
     )
-    transport = client._client._transport
+    transport = client.transport
 
     # Ensure that we have a api-core operations client.
     assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
@@ -996,6 +1015,107 @@ def test_asset_service_grpc_lro_async_client():
     assert transport.operations_client is transport.operations_client
 
 
+def test_common_billing_account_path():
+    billing_account = "squid"
+
+    expected = "billingAccounts/{billing_account}".format(
+        billing_account=billing_account,
+    )
+    actual = AssetServiceClient.common_billing_account_path(billing_account)
+    assert expected == actual
+
+
+def test_parse_common_billing_account_path():
+    expected = {
+        "billing_account": "clam",
+    }
+    path = AssetServiceClient.common_billing_account_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_billing_account_path(path)
+    assert expected == actual
+
+
+def test_common_folder_path():
+    folder = "whelk"
+
+    expected = "folders/{folder}".format(folder=folder,)
+    actual = AssetServiceClient.common_folder_path(folder)
+    assert expected == actual
+
+
+def test_parse_common_folder_path():
+    expected = {
+        "folder": "octopus",
+    }
+    path = AssetServiceClient.common_folder_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_folder_path(path)
+    assert expected == actual
+
+
+def test_common_organization_path():
+    organization = "oyster"
+
+    expected = "organizations/{organization}".format(organization=organization,)
+    actual = AssetServiceClient.common_organization_path(organization)
+    assert expected == actual
+
+
+def test_parse_common_organization_path():
+    expected = {
+        "organization": "nudibranch",
+    }
+    path = AssetServiceClient.common_organization_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_organization_path(path)
+    assert expected == actual
+
+
+def test_common_project_path():
+    project = "cuttlefish"
+
+    expected = "projects/{project}".format(project=project,)
+    actual = AssetServiceClient.common_project_path(project)
+    assert expected == actual
+
+
+def test_parse_common_project_path():
+    expected = {
+        "project": "mussel",
+    }
+    path = AssetServiceClient.common_project_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_project_path(path)
+    assert expected == actual
+
+
+def test_common_location_path():
+    project = "winkle"
+    location = "nautilus"
+
+    expected = "projects/{project}/locations/{location}".format(
+        project=project, location=location,
+    )
+    actual = AssetServiceClient.common_location_path(project, location)
+    assert expected == actual
+
+
+def test_parse_common_location_path():
+    expected = {
+        "project": "scallop",
+        "location": "abalone",
+    }
+    path = AssetServiceClient.common_location_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_location_path(path)
+    assert expected == actual
+
+
 def test_client_withDEFAULT_CLIENT_INFO():
     client_info = gapic_v1.client_info.ClientInfo()
 
