@@ -91,12 +91,12 @@ def test_asset_service_client_from_service_account_file(client_class):
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
         client = client_class.from_service_account_json("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
-        assert client._transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_client_get_transport_class():
@@ -440,7 +440,7 @@ def test_list_assets(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_assets), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = asset_service.ListAssetsResponse(
             next_page_token="next_page_token_value",
@@ -455,6 +455,7 @@ def test_list_assets(
         assert args[0] == asset_service.ListAssetsRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, pagers.ListAssetsPager)
 
     assert response.next_page_token == "next_page_token_value"
@@ -465,19 +466,19 @@ def test_list_assets_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_list_assets_async(transport: str = "grpc_asyncio"):
+async def test_list_assets_async(
+    transport: str = "grpc_asyncio", request_type=asset_service.ListAssetsRequest
+):
     client = AssetServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = asset_service.ListAssetsRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_assets), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.ListAssetsResponse(next_page_token="next_page_token_value",)
@@ -489,7 +490,7 @@ async def test_list_assets_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == asset_service.ListAssetsRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, pagers.ListAssetsAsyncPager)
@@ -497,6 +498,11 @@ async def test_list_assets_async(transport: str = "grpc_asyncio"):
     assert response.next_page_token == "next_page_token_value"
 
 
+@pytest.mark.asyncio
+async def test_list_assets_async_from_dict():
+    await test_list_assets_async(request_type=dict)
+
+
 def test_list_assets_field_headers():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -506,7 +512,7 @@ def test_list_assets_field_headers():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_assets), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         call.return_value = asset_service.ListAssetsResponse()
 
         client.list_assets(request)
@@ -531,9 +537,7 @@ async def test_list_assets_field_headers_async():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_assets), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             asset_service.ListAssetsResponse()
         )
@@ -554,7 +558,7 @@ def test_list_assets_pager():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_assets), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
@@ -586,7 +590,7 @@ def test_list_assets_pages():
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_assets), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
@@ -611,9 +615,7 @@ async def test_list_assets_async_pager():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.list_assets),
-        "__call__",
-        new_callable=mock.AsyncMock,
+        type(client.transport.list_assets), "__call__", new_callable=mock.AsyncMock
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -644,9 +646,7 @@ async def test_list_assets_async_pages():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.list_assets),
-        "__call__",
-        new_callable=mock.AsyncMock,
+        type(client.transport.list_assets), "__call__", new_callable=mock.AsyncMock
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -704,7 +704,7 @@ def test_transport_instance():
         credentials=credentials.AnonymousCredentials(),
     )
     client = AssetServiceClient(transport=transport)
-    assert client._transport is transport
+    assert client.transport is transport
 
 
 def test_transport_get_channel():
@@ -737,7 +737,7 @@ def test_transport_adc(transport_class):
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client._transport, transports.AssetServiceGrpcTransport,)
+    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
 
 
 def test_asset_service_base_transport_error():
@@ -829,7 +829,7 @@ def test_asset_service_host_no_port():
             api_endpoint="cloudasset.googleapis.com"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:443"
+    assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
 def test_asset_service_host_with_port():
@@ -839,7 +839,7 @@ def test_asset_service_host_with_port():
             api_endpoint="cloudasset.googleapis.com:8000"
         ),
     )
-    assert client._transport._host == "cloudasset.googleapis.com:8000"
+    assert client.transport._host == "cloudasset.googleapis.com:8000"
 
 
 def test_asset_service_grpc_transport_channel():
@@ -851,6 +851,7 @@ def test_asset_service_grpc_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 def test_asset_service_grpc_asyncio_transport_channel():
@@ -862,6 +863,7 @@ def test_asset_service_grpc_asyncio_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 @pytest.mark.parametrize(
@@ -904,6 +906,7 @@ def test_asset_service_transport_channel_mtls_with_client_cert_source(transport_
                 quota_project_id=None,
             )
             assert transport.grpc_channel == mock_grpc_channel
+            assert transport._ssl_channel_credentials == mock_ssl_cred
 
 
 @pytest.mark.parametrize(
@@ -943,6 +946,114 @@ def test_asset_service_transport_channel_mtls_with_adc(transport_class):
             assert transport.grpc_channel == mock_grpc_channel
 
 
+def test_asset_path():
+
+    expected = "*".format()
+    actual = AssetServiceClient.asset_path()
+    assert expected == actual
+
+
+def test_common_billing_account_path():
+    billing_account = "squid"
+
+    expected = "billingAccounts/{billing_account}".format(
+        billing_account=billing_account,
+    )
+    actual = AssetServiceClient.common_billing_account_path(billing_account)
+    assert expected == actual
+
+
+def test_parse_common_billing_account_path():
+    expected = {
+        "billing_account": "clam",
+    }
+    path = AssetServiceClient.common_billing_account_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_billing_account_path(path)
+    assert expected == actual
+
+
+def test_common_folder_path():
+    folder = "whelk"
+
+    expected = "folders/{folder}".format(folder=folder,)
+    actual = AssetServiceClient.common_folder_path(folder)
+    assert expected == actual
+
+
+def test_parse_common_folder_path():
+    expected = {
+        "folder": "octopus",
+    }
+    path = AssetServiceClient.common_folder_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_folder_path(path)
+    assert expected == actual
+
+
+def test_common_organization_path():
+    organization = "oyster"
+
+    expected = "organizations/{organization}".format(organization=organization,)
+    actual = AssetServiceClient.common_organization_path(organization)
+    assert expected == actual
+
+
+def test_parse_common_organization_path():
+    expected = {
+        "organization": "nudibranch",
+    }
+    path = AssetServiceClient.common_organization_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_organization_path(path)
+    assert expected == actual
+
+
+def test_common_project_path():
+    project = "cuttlefish"
+
+    expected = "projects/{project}".format(project=project,)
+    actual = AssetServiceClient.common_project_path(project)
+    assert expected == actual
+
+
+def test_parse_common_project_path():
+    expected = {
+        "project": "mussel",
+    }
+    path = AssetServiceClient.common_project_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_project_path(path)
+    assert expected == actual
+
+
+def test_common_location_path():
+    project = "winkle"
+    location = "nautilus"
+
+    expected = "projects/{project}/locations/{location}".format(
+        project=project, location=location,
+    )
+    actual = AssetServiceClient.common_location_path(project, location)
+    assert expected == actual
+
+
+def test_parse_common_location_path():
+    expected = {
+        "project": "scallop",
+        "location": "abalone",
+    }
+    path = AssetServiceClient.common_location_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_common_location_path(path)
+    assert expected == actual
+
+
 def test_client_withDEFAULT_CLIENT_INFO():
     client_info = gapic_v1.client_info.ClientInfo()
 
